﻿using UnityEngine;
using System.Collections;

public class TransformObject : Interactable {

	public enum Transformation {
		Movement, Rotation
	}

	public Transformation transformation;
	public Vector3 transVector;
	public float speed = 1;

	private Vector3 orVector;
	private bool interacted = true;

	void Awake() {
		switch (transformation) {
			case Transformation.Movement:
				orVector = transform.position;
				break;
			case Transformation.Rotation:
				orVector = transform.eulerAngles;
				break;
			default:
				orVector = Vector3.zero;
				break;
		}
		message = "E to Open";
	}

	public override void Interact() {
		StopAllCoroutines();
		interacted = !interacted;
		message = (interacted) ? "E to Open" : "E to Close";
		UIManager.instance.SetPrompt(message);
		StartCoroutine(PerformTransformation());
	}

	IEnumerator PerformTransformation() {
		float tParam = 0;
		Vector3 vector, startVector;
		Vector3 goalVector = orVector + transVector;
		startVector = (transformation == Transformation.Movement) ? transform.position : transform.eulerAngles;
		while (tParam < 1) {
			tParam += Time.deltaTime * speed;
			vector = (interacted) ? Vector3.Lerp(startVector, orVector, tParam) : Vector3.Lerp(startVector, goalVector, tParam);
			switch (transformation) {
				case Transformation.Movement:
					transform.position = vector;
					break;
				case Transformation.Rotation:
					transform.eulerAngles = vector;
					break;
			}
			yield return null;
		}
	}

}
